==> ejc-wzxt-api-3.0.0-20210906.010649-111-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long parentId; // parent_id
    private Long tid;
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal nums; // 审批数量
    private java.math.BigDecimal planNum; // 需求数量
    private java.math.BigDecimal occupyNums; // 占用数量
    private java.math.BigDecimal surplusNums; // 剩余数量
    private java.math.BigDecimal planNumsSum; // 所有需求数量
    private java.math.BigDecimal occupyNumsAll; // 所有占用数量
    private java.math.BigDecimal surplusNumsSum; // 所有剩余数量
    private String memo; // 备注
    private List<PlanDetailRefVO> planDetail; //
    private String construction; //施工部位

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public List<PlanDetailRefVO> getPlanDetail() {
        return planDetail;
    }

    public void setPlanDetail(List<PlanDetailRefVO> planDetail) {
        this.planDetail = planDetail;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }


    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
}

==> ejc-wzxt-api-3.0.0-20211104.111550-117-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long parentId; // parent_id
    private Long tid;
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private BigDecimal nums; // 审批数量
    private BigDecimal planNum; // 需求数量
    private BigDecimal occupyNums; // 占用数量
    private BigDecimal surplusNums; // 剩余数量
    private BigDecimal planNumsSum; // 所有需求数量
    private BigDecimal occupyNumsAll; // 所有占用数量
    private BigDecimal surplusNumsSum; // 所有剩余数量
    private String memo; // 备注
    private List<PlanDetailRefVO> planDetail; //
    private String construction; //施工部位
    private Long materialSourceId; // 物资来源主键

    private String constructionId;

    private BigDecimal jhl; // PM计划量

    private BigDecimal planNumSum; // 累计计划量

    public Long getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(Long materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getConstructionId() {
        return constructionId;
    }

    public void setConstructionId(String constructionId) {
        this.constructionId = constructionId;
    }

    public BigDecimal getJhl() {
        return jhl;
    }

    public void setJhl(BigDecimal jhl) {
        this.jhl = jhl;
    }

    public BigDecimal getPlanNumSum() {
        return planNumSum;
    }

    public void setPlanNumSum(BigDecimal planNumSum) {
        this.planNumSum = planNumSum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public List<PlanDetailRefVO> getPlanDetail() {
        return planDetail;
    }

    public void setPlanDetail(List<PlanDetailRefVO> planDetail) {
        this.planDetail = planDetail;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }


    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
}
